@@ -1,30 +1,28 @@
 
 package Importer::Zim::Lexical;
-$Importer::Zim::Lexical::VERSION = '0.7.0';
+$Importer::Zim::Lexical::VERSION = '0.8.0';
 # ABSTRACT: Import functions as lexical subroutines
 
 use 5.018;
 
-BEGIN {
-    require Importer::Zim::Base;
-    Importer::Zim::Base->VERSION('0.5.0');
-    our @ISA = qw(Importer::Zim::Base);
-}
+use Importer::Zim::Base 0.8.0;
+BEGIN { our @ISA = qw(Importer::Zim::Base); }
 
-use Sub::Inject ();
-
-use constant DEBUG => $ENV{IMPORTER_ZIM_DEBUG} || 0;
+use Sub::Inject 0.2.0;
+use Importer::Zim::Utils 0.8.0 qw(DEBUG carp);
 
 sub import {
     my $class = shift;
 
-    warn "$class->import(@_)\n" if DEBUG;
+    carp "$class->import(@_)" if DEBUG;
     my @exports = $class->_prepare_args(@_);
 
     @_ = map { @{$_}{qw(export code)} } @exports;
     goto &Sub::Inject::sub_inject;
 }
 
+no Importer::Zim::Utils qw(DEBUG carp);
+
 1;
 
 #pod =encoding utf8
@@ -75,7 +73,7 @@ Importer::Zim::Lexical - Import functions as lexical subroutines
 
 =head1 VERSION
 
-version 0.7.0
+version 0.8.0
 
 =head1 SYNOPSIS
 
